@@ -10,38 +10,38 @@
 from __future__ import annotations
 
 import logging
-from typing import List, Dict, Any
+from typing import Any, Dict, List
 
+from ..pdi.constants import D4Action, IrdaAction, PdiCommand
+from ..pdi.d4_req import D4Req
+from ..pdi.irda_req import IrdaReq
+from ..protocol.command_def import CommandDefEnum
+from ..protocol.command_req import CommandReq
+from ..protocol.constants import (
+    CONTROL_TYPE,
+    LEGACY_CONTROL_TYPE,
+    LOCO_CLASS,
+    LOCO_TRACK_CRANE,
+    LOCO_TYPE,
+    RPM_TYPE,
+    SOUND_TYPE,
+    STEAM_TYPE,
+    TRACK_CRANE_STATE_NUMERICS,
+    CommandScope,
+)
+from ..protocol.multibyte.multibyte_constants import TMCC2EffectsControl
+from ..protocol.tmcc1.tmcc1_constants import TMCC1_COMMAND_TO_ALIAS_MAP, TMCC1EngineCommandEnum, TMCC1HaltCommandEnum
+from ..protocol.tmcc1.tmcc1_constants import TMCC1EngineCommandEnum as TMCC1
+from ..protocol.tmcc2.tmcc2_constants import TMCC2_COMMAND_TO_ALIAS_MAP, TMCC2EngineCommandEnum
+from ..protocol.tmcc2.tmcc2_constants import TMCC2EngineCommandEnum as TMCC2
+from .comp_data import CompDataHandler, CompDataMixin
 from .component_state import (
+    SCOPE_TO_STATE_MAP,
+    ComponentState,
     L,
     P,
     log,
-    SCOPE_TO_STATE_MAP,
-    ComponentState,
 )
-from ..pdi.d4_req import D4Req
-from .comp_data import CompDataMixin, CompDataHandler
-from ..protocol.multibyte.multibyte_constants import TMCC2EffectsControl
-from ..protocol.command_req import CommandReq
-from ..protocol.command_def import CommandDefEnum
-from ..pdi.constants import PdiCommand, IrdaAction, D4Action
-from ..pdi.irda_req import IrdaReq
-from ..protocol.constants import (
-    LOCO_TYPE,
-    CONTROL_TYPE,
-    LOCO_TRACK_CRANE,
-    TRACK_CRANE_STATE_NUMERICS,
-    RPM_TYPE,
-    STEAM_TYPE,
-    CommandScope,
-    LOCO_CLASS,
-    SOUND_TYPE,
-    LEGACY_CONTROL_TYPE,
-)
-from ..protocol.tmcc1.tmcc1_constants import TMCC1_COMMAND_TO_ALIAS_MAP, TMCC1EngineCommandEnum, TMCC1HaltCommandEnum
-from ..protocol.tmcc2.tmcc2_constants import TMCC2_COMMAND_TO_ALIAS_MAP, TMCC2EngineCommandEnum
-from ..protocol.tmcc1.tmcc1_constants import TMCC1EngineCommandEnum as TMCC1
-from ..protocol.tmcc2.tmcc2_constants import TMCC2EngineCommandEnum as TMCC2
 
 DIRECTIONS_SET = {
     TMCC1EngineCommandEnum.FORWARD_DIRECTION,
@@ -208,7 +208,7 @@ class EngineState(ComponentState):
 
     def decode_speed_info(self, speed_info):
         if speed_info is not None and speed_info == 255:  # not set
-            if self.is_legacy:
+            if self.is_legacy is True:
                 speed_info = 195
             else:
                 speed_info = 31
@@ -244,7 +244,7 @@ class EngineState(ComponentState):
 
                 # handle some aspects of the halt command
                 if command.command == TMCC1HaltCommandEnum.HALT:
-                    if self.is_legacy:
+                    if self.is_legacy is True:
                         self._aux1 = TMCC2.AUX1_OFF
                         self._aux2 = TMCC2.AUX2_OFF
                         self._aux = TMCC2.AUX2_OPTION_ONE
@@ -316,7 +316,7 @@ class EngineState(ComponentState):
                         self._aux = cmd if cmd in {TMCC1.AUX2_OPTION_ONE, TMCC2.AUX2_OPTION_ONE} else self._aux
                         if cmd in {TMCC1.AUX2_OPTION_ONE, TMCC2.AUX2_OPTION_ONE}:
                             if self.time_delta(self._last_updated, self._last_aux2_opt1) > 1:
-                                if self.is_legacy:
+                                if self._is_legacy is True:
                                     self._aux2 = self.update_aux_state(
                                         self._aux2,
                                         TMCC2.AUX2_ON,
@@ -340,7 +340,7 @@ class EngineState(ComponentState):
                             TMCC2.AUX2_OPTION_TWO,
                         }:
                             self._aux2 = cmd
-                            self._last_aux2_opt1 = self.last_updated
+                            # self._last_aux2_opt1 = self.last_updated
 
                 # handle run level/rpm
                 if command.command in RPM_SET:
@@ -548,7 +548,7 @@ class EngineState(ComponentState):
         elif self.max_speed and self.max_speed != 255:
             ms = self.max_speed
         else:
-            ms = 199 if self.is_legacy else 31
+            ms = 199 if self.is_legacy is True else 31
         if self.is_legacy is False and ms > 31:
             ms = 31
         return ms
